@@ -40,6 +40,23 @@ describe TestCase, 'markdown extraction':
                 builder = pjs.ObjectBuilder(ex, resolved=self.examples)
                 builder.should.be.ok
 
+        context "oneOf":
+            before_each:
+                builder = pjs.ObjectBuilder(self.examples['OneOf'], resolved=self.examples)
+                builder.should.be.ok
+                self.OneOf = builder.classes['Oneof']
+
+            it 'should validate against any of the provided schemas':
+
+                self.OneOf.from_json.when.called_with('{"MyData": "an address"}').should_not.throw()
+                self.OneOf.from_json.when.called_with('{"MyData": 1234}').should_not.throw()
+
+            it 'should fail to validate when given something that does not match':
+                self.OneOf.from_json.when.called_with(
+                    '{"MyData": 1234.234}'
+                ).should.throw(pjs.ValidationError)
+
+
         context "additionalProperties":
 
             before_each:
@@ -60,6 +77,13 @@ describe TestCase, 'markdown extraction':
 
                 int(person.randomAttribute).should.equal(4)
 
+            it 'should be oky with additionalProperties == True':
+                builder = pjs.ObjectBuilder(self.examples['AddlPropsAllowed'], resolved=self.examples)
+                builder.should.be.ok
+
+                test = builder.classes['Addlpropsallowed']()
+                test.randomAttribute = 40
+
             it 'should still raise errors when accessing undefined attributes':
 
                 person = self.Person()
